#[non_exhaustive]pub struct BatchGetPreparedStatementInputBuilder { /* private fields */ }Expand description
A builder for BatchGetPreparedStatementInput.
Implementations
Sourceimpl BatchGetPreparedStatementInputBuilder
impl BatchGetPreparedStatementInputBuilder
Sourcepub fn prepared_statement_names(self, input: impl Into<String>) -> Self
pub fn prepared_statement_names(self, input: impl Into<String>) -> Self
Appends an item to prepared_statement_names.
To override the contents of this collection use set_prepared_statement_names.
A list of prepared statement names to return.
Sourcepub fn set_prepared_statement_names(self, input: Option<Vec<String>>) -> Self
pub fn set_prepared_statement_names(self, input: Option<Vec<String>>) -> Self
A list of prepared statement names to return.
Sourcepub fn get_prepared_statement_names(&self) -> &Option<Vec<String>>
pub fn get_prepared_statement_names(&self) -> &Option<Vec<String>>
A list of prepared statement names to return.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The name of the workgroup to which the prepared statements belong.
This field is required.Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The name of the workgroup to which the prepared statements belong.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The name of the workgroup to which the prepared statements belong.
Sourcepub fn build(self) -> Result<BatchGetPreparedStatementInput, BuildError>
pub fn build(self) -> Result<BatchGetPreparedStatementInput, BuildError>
Consumes the builder and constructs a BatchGetPreparedStatementInput.
Sourceimpl BatchGetPreparedStatementInputBuilder
impl BatchGetPreparedStatementInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<BatchGetPreparedStatementOutput, SdkError<BatchGetPreparedStatementError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<BatchGetPreparedStatementOutput, SdkError<BatchGetPreparedStatementError, HttpResponse>>
Sends a request with this input using the given client.