#[non_exhaustive]pub struct BatchGetPreparedStatementOutputBuilder { /* private fields */ }Expand description
A builder for BatchGetPreparedStatementOutput.
Implementations
Sourceimpl BatchGetPreparedStatementOutputBuilder
impl BatchGetPreparedStatementOutputBuilder
Sourcepub fn prepared_statements(self, input: PreparedStatement) -> Self
pub fn prepared_statements(self, input: PreparedStatement) -> Self
Appends an item to prepared_statements.
To override the contents of this collection use set_prepared_statements.
The list of prepared statements returned.
Sourcepub fn set_prepared_statements(
self,
input: Option<Vec<PreparedStatement>>,
) -> Self
pub fn set_prepared_statements( self, input: Option<Vec<PreparedStatement>>, ) -> Self
The list of prepared statements returned.
Sourcepub fn get_prepared_statements(&self) -> &Option<Vec<PreparedStatement>>
pub fn get_prepared_statements(&self) -> &Option<Vec<PreparedStatement>>
The list of prepared statements returned.
Sourcepub fn unprocessed_prepared_statement_names(
self,
input: UnprocessedPreparedStatementName,
) -> Self
pub fn unprocessed_prepared_statement_names( self, input: UnprocessedPreparedStatementName, ) -> Self
Appends an item to unprocessed_prepared_statement_names.
To override the contents of this collection use set_unprocessed_prepared_statement_names.
A list of one or more prepared statements that were requested but could not be returned.
Sourcepub fn set_unprocessed_prepared_statement_names(
self,
input: Option<Vec<UnprocessedPreparedStatementName>>,
) -> Self
pub fn set_unprocessed_prepared_statement_names( self, input: Option<Vec<UnprocessedPreparedStatementName>>, ) -> Self
A list of one or more prepared statements that were requested but could not be returned.
Sourcepub fn get_unprocessed_prepared_statement_names(
&self,
) -> &Option<Vec<UnprocessedPreparedStatementName>>
pub fn get_unprocessed_prepared_statement_names( &self, ) -> &Option<Vec<UnprocessedPreparedStatementName>>
A list of one or more prepared statements that were requested but could not be returned.
Sourcepub fn build(self) -> BatchGetPreparedStatementOutput
pub fn build(self) -> BatchGetPreparedStatementOutput
Consumes the builder and constructs a BatchGetPreparedStatementOutput.